import { Observable, Unsubscribable } from 'rxjs';
import { IExtServices } from './ext-services';
import { IClientService } from '@adminide-stack/core';
import { IExecuteCommandParams } from './command';
export interface IController extends Unsubscribable {
    /**
     * Global notification messages that should be displayed to the user, from the following sources:
     *
     * - window/showMessage notifications from extensions
     * - Errors thrown or returned in command invocation
     */
    readonly notifications: Observable<Notification>;
    services: IExtServices & IClientService;
    /**
     * Executes the command (registered in the CommandRegistry) specified in params. If an error is thrown, the
     * error is retured *and* emitted on the {@link Controller#notifications} observable.
     *
     * All callers should execute commands using this method instead of calling
     * {@link cdeops:CommandRegistry#executbeCommand} directly (to ensure errors are emitted as notications).
     *
     * @param suppressNotificationOnError By default, if command execution throws (or rejects with) an error, the
     * error will be shown in the global notification UI component. Pass suppressNotificationOnError as true to
     * skip this. The error is always returned to the caller.
     */
    executeCommand(params: IExecuteCommandParams, suppressNotificationOnError?: boolean): Promise<any>;
    /**
     * Frees all resources associated with this client.
     */
    unsubscribe(): void;
}
